@@ -9,10 +9,11 @@ from termcolor import colored
 from aiosumma import SummaClient
 
 
-async def client_cli(endpoint):
+async def client_cli(endpoint: str = '127.0.0.1:8082'):
     try:
         client = SummaClient(endpoint=endpoint, connection_timeout=3.0)
         await client.start()
+        print(f"{colored('SERVER_RESPONDED', 'green')}:", file=sys.stderr)
         return client.get_interface()
     except asyncio.exceptions.TimeoutError:
         # ToDo: process exception through fire.core.FireError
